@@ -56,8 +56,8 @@ import lombok.AllArgsConstructor;
 import lombok.NonNull;
 import lombok.RequiredArgsConstructor;
 import lombok.Value;
+import lombok.With;
 import lombok.experimental.NonFinal;
-import lombok.experimental.Wither;
 
 @Value
 @AllArgsConstructor(access = AccessLevel.PRIVATE)
@@ -72,31 +72,35 @@ public class LoginCredentials {
 
     String clientId;
 
-    @Wither
+    @With
     @NonFinal
     String remoteIp;
 
-    @Wither
+    @With
     @NonFinal
     String host;
 
-    @Wither
+    @With
+    @NonFinal
+    String xHost;
+
+    @With
     @NonFinal
     String forwardedFor;
 
-    @Wither
+    @With
     @NonFinal
     String forwardedProto;
 
-    @Wither
+    @With
     @NonFinal
     String userAgent;
 
-    @Wither
+    @With
     @NonFinal
     String trackingId;
 
-    @Wither
+    @With
     @NonFinal
     HostConfiguration hostConfiguration;
 
